@@ -111,6 +111,7 @@ from alfasim_sdk._internal.alfacase.case_description import PhysicsDescription
 from alfasim_sdk._internal.alfacase.case_description import PigEquipmentDescription
 from alfasim_sdk._internal.alfacase.case_description import PipeDescription
 from alfasim_sdk._internal.alfacase.case_description import PipeSegmentsDescription
+from alfasim_sdk._internal.alfacase.case_description import PluginDescription
 from alfasim_sdk._internal.alfacase.case_description import (
     PressureContainerDescription,
 )
@@ -217,8 +218,11 @@ from alfasim_sdk._internal.alfacase.alfatable import (
 from alfasim_sdk._internal.constants import BUBBLE_FIELD
 from alfasim_sdk._internal.constants import CompressorSpeedType
 from alfasim_sdk._internal.constants import ControllerType
+from alfasim_sdk._internal.constants import CorrelationsGasViscosity
+from alfasim_sdk._internal.constants import CorrelationsOilViscosity
 from alfasim_sdk._internal.constants import CorrelationPackage
 from alfasim_sdk._internal.constants import CorrelationPackageType
+from alfasim_sdk._internal.constants import CorrelationsSurfaceTension
 from alfasim_sdk._internal.constants import DEFAULT_TEMPERATURE_IN_K
 from alfasim_sdk._internal.constants import DrainageRateMode
 from alfasim_sdk._internal.constants import DROPLET_FIELD
@@ -230,6 +234,7 @@ from alfasim_sdk._internal.constants import EnergyModel
 from alfasim_sdk._internal.constants import EnergyModelPrimaryVariable
 from alfasim_sdk._internal.constants import EquationOfStateType
 from alfasim_sdk._internal.constants import EquipmentAttachmentLocation
+from alfasim_sdk._internal.constants import EspParameters
 from alfasim_sdk._internal.constants import EvaluationStrategyType
 from alfasim_sdk._internal.constants import EXTRAS_REQUIRED_VERSION_KEY
 from alfasim_sdk._internal.constants import FlashModel
@@ -267,6 +272,7 @@ from alfasim_sdk._internal.constants import (
 from alfasim_sdk._internal.constants import PipeThermalModelType
 from alfasim_sdk._internal.constants import PipeThermalPositionInput
 from alfasim_sdk._internal.constants import PumpType
+from alfasim_sdk._internal.constants import PumpViscosityModel
 from alfasim_sdk._internal.constants import PVTCompositionalViscosityModel
 from alfasim_sdk._internal.constants import SeparatorGeometryType
 from alfasim_sdk._internal.constants import SimulationModeType
@@ -285,9 +291,7 @@ from alfasim_sdk._internal.constants import WATER_LAYER
 from alfasim_sdk._internal.constants import WATER_PHASE
 from alfasim_sdk._internal.constants import WellConnectionPort
 from alfasim_sdk._internal.constants import WellIndexPhaseType
-from alfasim_sdk._internal.constants import CorrelationsOilViscosity
-from alfasim_sdk._internal.constants import CorrelationsGasViscosity
-from alfasim_sdk._internal.constants import CorrelationsSurfaceTension
+
 
 # Plugins: Layouts imports
 from alfasim_sdk._internal.layout import tab
@@ -430,6 +434,7 @@ __all__ = [
     "MaterialDescription",
     "MaterialType",
     "MultiInputType",
+    "EspParameters",
     "MultipleReference",
     "NodeCellType",
     "NodeDescription",
@@ -452,6 +457,7 @@ __all__ = [
     "PipeSegmentsDescription",
     "PipeThermalModelType",
     "PipeThermalPositionInput",
+    "PluginDescription",
     "PositionalPipeTrendDescription",
     "PressureContainerDescription",
     "PressureNodePropertiesDescription",
@@ -459,6 +465,7 @@ __all__ = [
     "ProfileOutputDescription",
     "PumpEquipmentDescription",
     "PumpType",
+    "PumpViscosityModel",
     "PvtModelCombinedDescription",
     "PvtModelCompositionalDescription",
     "PvtModelCorrelationDescription",
